# Changelog

This is an auto-generated log of all the changes that have been made to the
project since the first release.

This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [1.2.0](https://github.com/gnramsay/oots-get/releases/tag/1.2.0) (2024-09-04)

**New Features**

- Migrate from 'argparse' to using 'Typer' for the CLI ([#76](https://github.com/gnramsay/oots-get/pull/76)) by [gnramsay](https://github.com/gnramsay)

**Refactoring**

- Refactor code into helper functions and optimize ([#77](https://github.com/gnramsay/oots-get/pull/77)) by [gnramsay](https://github.com/gnramsay)
- Migrate project structure to 'uv' ([#75](https://github.com/gnramsay/oots-get/pull/75)) by [gnramsay](https://github.com/gnramsay)

**Dependency Updates**

- Relax dep version spec and update deps ([#74](https://github.com/gnramsay/oots-get/pull/74)) by [gnramsay](https://github.com/gnramsay)
- Bump ruff from 0.3.5 to 0.5.1 ([#71](https://github.com/gnramsay/oots-get/pull/71)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump certifi from 2023.11.17 to 2024.7.4 ([#70](https://github.com/gnramsay/oots-get/pull/70)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pre-commit from 3.6.0 to 3.7.0 ([#38](https://github.com/gnramsay/oots-get/pull/38)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump types-beautifulsoup4 from 4.12.0.20240106 to 4.12.0.20240229 ([#37](https://github.com/gnramsay/oots-get/pull/37)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump poethepoet from 0.24.4 to 0.25.0 ([#36](https://github.com/gnramsay/oots-get/pull/36)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump lxml from 5.1.0 to 5.2.1 ([#35](https://github.com/gnramsay/oots-get/pull/35)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump rich from 13.7.0 to 13.7.1 ([#34](https://github.com/gnramsay/oots-get/pull/34)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mypy from 1.8.0 to 1.9.0 ([#33](https://github.com/gnramsay/oots-get/pull/33)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump types-requests from 2.31.0.20240106 to 2.31.0.20240406 ([#32](https://github.com/gnramsay/oots-get/pull/32)) by [dependabot[bot]](https://github.com/apps/dependabot)
- *and 4 more dependency updates*

[`Full Changelog`](https://github.com/gnramsay/oots-get/compare/v1.1.1...1.2.0) | [`Diff`](https://github.com/gnramsay/oots-get/compare/v1.1.1...1.2.0.diff) | [`Patch`](https://github.com/gnramsay/oots-get/compare/v1.1.1...1.2.0.patch)

## [v1.1.1](https://github.com/gnramsay/oots-get/releases/tag/v1.1.1) (2024-01-16)

**_You fail your save vs typos_**

- Update the comic storage folder to be correct.

[`Full Changelog`](https://github.com/gnramsay/oots-get/compare/v1.1.0...v1.1.1) | [`Diff`](https://github.com/gnramsay/oots-get/compare/v1.1.0...v1.1.1.diff) | [`Patch`](https://github.com/gnramsay/oots-get/compare/v1.1.0...v1.1.1.patch)

## [v1.1.0](https://github.com/gnramsay/oots-get/releases/tag/v1.1.0) (2024-01-16) **[`YANKED`]**

**This release has been removed for the following reason and should not be used:**

- Incorrect folder for comic storage

**_New Dice Please_**

**Refactoring**

- Update tooling and fix all linting/type warnings, migrate to Pathlib for all file operations ([#7](https://github.com/gnramsay/oots-get/pull/7)) by [seapagan](https://github.com/seapagan)

[`Full Changelog`](https://github.com/gnramsay/oots-get/compare/v1.1.0b-beta-1...v1.1.0) | [`Diff`](https://github.com/gnramsay/oots-get/compare/v1.1.0b-beta-1...v1.1.0.diff) | [`Patch`](https://github.com/gnramsay/oots-get/compare/v1.1.0b-beta-1...v1.1.0.patch)

## [v1.1.0b-beta-1](https://github.com/gnramsay/oots-get/releases/tag/v1.1.0b-beta-1) (2024-01-16)

**_Stick With It_**

**Refactoring**

- Migrate to Poetry ([#4](https://github.com/gnramsay/oots-get/pull/4)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump github/codeql-action from 1 to 3 ([#6](https://github.com/gnramsay/oots-get/pull/6)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump actions/checkout from 2 to 4 ([#5](https://github.com/gnramsay/oots-get/pull/5)) by [dependabot[bot]](https://github.com/apps/dependabot)

[`Full Changelog`](https://github.com/gnramsay/oots-get/compare/v1.0.3...v1.1.0b-beta-1) | [`Diff`](https://github.com/gnramsay/oots-get/compare/v1.0.3...v1.1.0b-beta-1.diff) | [`Patch`](https://github.com/gnramsay/oots-get/compare/v1.0.3...v1.1.0b-beta-1.patch)

## [v1.0.3](https://github.com/gnramsay/oots-get/releases/tag/v1.0.3) (2022-04-26)

**_Roll again_**

Production/Stable release.
[`Full Changelog`](https://github.com/gnramsay/oots-get/compare/v1.0.1...v1.0.3) | [`Diff`](https://github.com/gnramsay/oots-get/compare/v1.0.1...v1.0.3.diff) | [`Patch`](https://github.com/gnramsay/oots-get/compare/v1.0.1...v1.0.3.patch)

## [v1.0.1](https://github.com/gnramsay/oots-get/releases/tag/v1.0.1) (2022-04-26)

**_Roll the dice_**

First public non-beta version.
Wheel and tgz attached to this release.
[`Full Changelog`](https://github.com/gnramsay/oots-get/compare/1.0.0b4...v1.0.1) | [`Diff`](https://github.com/gnramsay/oots-get/compare/1.0.0b4...v1.0.1.diff) | [`Patch`](https://github.com/gnramsay/oots-get/compare/1.0.0b4...v1.0.1.patch)

## [1.0.0b4](https://github.com/gnramsay/oots-get/releases/tag/1.0.0b4) (2022-04-09)

**_Beta 4_**

Fixed bug causing crash, tidied code
[`Full Changelog`](https://github.com/gnramsay/oots-get/compare/1.0.0b3...1.0.0b4) | [`Diff`](https://github.com/gnramsay/oots-get/compare/1.0.0b3...1.0.0b4.diff) | [`Patch`](https://github.com/gnramsay/oots-get/compare/1.0.0b3...1.0.0b4.patch)

## [1.0.0b3](https://github.com/gnramsay/oots-get/releases/tag/1.0.0b3) (2021-08-01)

**_Beta 3_**

**Merged Pull Requests**

- Add '--only-new' comand line option ([#2](https://github.com/gnramsay/oots-get/pull/2)) by [gnramsay](https://github.com/gnramsay)

[`Full Changelog`](https://github.com/gnramsay/oots-get/compare/1.0.0b2...1.0.0b3) | [`Diff`](https://github.com/gnramsay/oots-get/compare/1.0.0b2...1.0.0b3.diff) | [`Patch`](https://github.com/gnramsay/oots-get/compare/1.0.0b2...1.0.0b3.patch)

## [1.0.0b2](https://github.com/gnramsay/oots-get/releases/tag/1.0.0b2) (2021-07-11)

**_Beta 2_**

**Merged Pull Requests**

- Remove scaffold ([#1](https://github.com/gnramsay/oots-get/pull/1)) by [gnramsay](https://github.com/gnramsay)

[`Full Changelog`](https://github.com/gnramsay/oots-get/compare/1.0.0b1...1.0.0b2) | [`Diff`](https://github.com/gnramsay/oots-get/compare/1.0.0b1...1.0.0b2.diff) | [`Patch`](https://github.com/gnramsay/oots-get/compare/1.0.0b1...1.0.0b2.patch)

## [1.0.0b1](https://github.com/gnramsay/oots-get/releases/tag/1.0.0b1) (2021-07-10)

**_Beta 1_**

Beta pre-release 1
---
*This changelog was generated using [github-changelog-md](http://changelog.seapagan.net/) by [Seapagan](https://github.com/seapagan)*
